@@ -2,13 +2,11 @@ from django.http import HttpResponse, Http404, HttpResponseRedirect
 from . import app_settings
 from django.views.static import serve
 import mimetypes
-from django.contrib.auth.decorators import login_required
 
 
 DOCUMENTATION_ROOT = 'index.html'
 
 
-@login_required
 def documentation(request, path):
     if path == '':
         path = DOCUMENTATION_ROOT
